import { useRef, useState, useCallback } from "react";
import dequal from "dequal";
import { UNKNOWN, OK, BAD, FAILED } from "../components/shared/StatusMessage";
import useInterval from "./useInterval";

export default (
  url,
  {
    ms = 20000,
    fetchOptions = {},
  } = {}
) => {
  const fetchOptsRef = useRef({});
  if (!dequal(fetchOptsRef.current, fetchOptions)) {
    fetchOptsRef.current = fetchOptions;
  }

  const [status, setStatus] = useState(UNKNOWN);

  const checkServer = useCallback(async () => {
    try {
      const res = await fetch(url, fetchOptsRef.current);
      if (res.ok) {
        setStatus(OK);
      } else {
        setStatus(BAD);
      }
    } catch (err) {
      setStatus(FAILED);
    }
  }, [url]);

  useInterval(checkServer, ms);

  return status;
}